@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
+from feed2maildir.converter import Converter
 from feed2maildir.loader import Loader
 from feed2maildir.reader import Reader
 
@@ -8,7 +9,7 @@ def main():
     loader = Loader()
     config = loader.config
     reader = Reader(config['feeds'])
-    return 0
+    converter = Converter(reader.feeds)
 
 if __name__ == '__main__':
     main()
